import Vue from 'vue'
import VueRouter from 'vue-router'
import axios from 'axios'

Vue.use(VueRouter)

const router = new VueRouter({
    mode: 'history',
    base: process.env.BASE_URL,
    scrollBehavior() {
        return {
            x: 0,
            y: 0
        }
    },
    routes: [
        {
            path: '/',
            name: 'index',
            component: () => import('@/views/dashboard/home.vue'),
            meta: {
                layout: 'full',
            },
        },
        {
            path: '/portal',
            name: 'portal',
            component: () => import('@/views/dashboard/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'portal',
                breadcrumb: [
                    {
                        text: 'portal',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/home',
            name: 'home',
            component: () => import('@/views/dashboard/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'home',
                breadcrumb: [
                    {
                        text: 'home',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/profile',
            name: 'profile',
            component: () => import('@/views/user/UsersEdit.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'profile',
                breadcrumb: [
                    {
                        text: 'profile',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/portal/login',
            name: 'login',
            pageTitle: 'login',
            component: () => import('@/views/Login.vue'),
            meta: {
                layout: 'full',
            },
        },
        {
            path: '/error-404',
            name: 'error-404',
            component: () => import('@/views/error/Error404.vue'),
            meta: {
                layout: 'full',
            },
        },
        {
            path: '/branding',
            name: 'branding',
            component: () => import('@/views/branding/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'branding',
                breadcrumb: [
                    {
                        text: 'branding',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/system',
            name: 'system',
            component: () => import('@/views/settings/System.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'system_configuration',
                breadcrumb: [
                    {
                        text: 'system_configuration',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/smtp',
            name: 'smtp',
            component: () => import('@/views/settings/Smtp.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'smtp_configuration',
                breadcrumb: [
                    {
                        text: 'smtp_configuration',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/api',
            name: 'api',
            component: () => import('@/views/settings/Api.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'api_setting',
                breadcrumb: [
                    {
                        text: 'api_setting',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/license',
            name: 'license',
            component: () => import('@/views/settings/License.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'license_config',
                breadcrumb: [
                    {
                        text: 'license_config',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates',
            name: 'templates',
            component: () => import('@/views/templates/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'templates',
                breadcrumb: [
                    {
                        text: 'templates',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/template/:id',
            name: 'template',
            component: () => import('@/views/templates/view.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'view_template',
                breadcrumb: [
                    {
                        text: 'templates',
                        to: {name: 'templates'}
                    },
                    {
                        text: 'view_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/template/:id/edit',
            name: 'template-edit',
            component: () => import('@/views/templates/edit.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'edit_template',
                breadcrumb: [
                    {
                        text: 'templates',
                        to: {name: 'templates'}
                    },
                    {
                        text: 'view_template',
                        to: {
                            name: 'template',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/manageports',
            name: 'manageports',
            component: () => import('@/views/manageports/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'manageports',
                breadcrumb: [
                    {
                        text: 'manageports',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/manageports/:id/edit',
            name: 'manageportsEdit',
            component: () => import('@/views/manageports/edit.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'edit_ports',
                breadcrumb: [
                    {
                        text: 'manageports',
                        to: {name: 'manageports'}
                    },
                    {
                        text: 'edit_ports',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/portsrange',
            name: 'portsrange',
            component: () => import('@/views/portsrange/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'portsrange',
                breadcrumb: [
                    {
                        text: 'portsrange',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcasters',
            name: 'broadcasters',
            component: () => import('@/views/broadcasters/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'broadcasters',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcasters/add',
            name: 'broadAdd',
            component: () => import('@/views/broadcasters/add.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'add_broadcaster',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        to: {name: 'broadcasters'}
                    },
                    {
                        text: 'add_broadcaster',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcasters/:id',
            name: 'brodView',
            props: route => ({id: Number(route.params.id)}),
            component: () => import('@/views/broadcasters/view.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'view_broadcaster',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        to: {name: 'broadcasters'}
                    },
                    {
                        text: 'view_broadcaster',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcasters/:id/edit',
            name: 'brodEdit',
            component: () => import('@/views/broadcasters/edit.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'edit_broadcaster',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        to: {name: 'broadcasters'}
                    },
                    {
                        text: 'view_broadcaster',
                        to: {
                            name: 'brodView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit_broadcaster',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/resellers',
            name: 'resellers',
            component: () => import('@/views/resellers/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'resellers',
                breadcrumb: [
                    {
                        text: 'resellers',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/resellers/:id/edit',
            name: 'resellerEdit',
            component: () => import('@/views/resellers/edit.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'edit_reseller',
                breadcrumb: [
                    {
                        text: 'resellers',
                        to: {name: 'resellers'}
                    },
                    {
                        text: 'view_resellers',
                        to: {
                            name: 'resellerView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit_reseller',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/resellers/add',
            name: 'resellerdAdd',
            component: () => import('@/views/resellers/add.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'add_reseller',
                breadcrumb: [
                    {
                        text: 'resellers',
                        to: {name: 'resellers'}
                    },
                    {
                        text: 'add_reseller',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/resellers/:id',
            name: 'resellerView',
            props: route => ({id: Number(route.params.id)}),
            component: () => import('@/views/resellers/view.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'view_resellers',
                breadcrumb: [
                    {
                        text: 'resellers',
                        to: {name: 'resellers'}
                    },
                    {
                        text: 'view_resellers',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/broadcasters',
            name: 'brodtemplate',
            component: () => import('@/views/help-templates/broadcasters/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'broadcasters_templates',
                breadcrumb: [
                    {
                        text: 'broadcasters_templates',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/broadcasters/add',
            name: 'brodTemplateAdd',
            component: () => import('@/views/help-templates/broadcasters/add.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'add_broadcaster_template',
                breadcrumb: [
                    {
                        text: 'broadcasters_templates',
                        to: {name: 'brodtemplate'}
                    },
                    {
                        text: 'add_new_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/broadcasters/:id',
            name: 'brodTemplateView',
            component: () => import('@/views/help-templates/broadcasters/view.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'view_broadcaster_template',
                breadcrumb: [
                    {
                        text: 'broadcasters_template',
                        to: {name: 'brodtemplate'}
                    },
                    {
                        text: 'view_broadcaster_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/broadcasters/:id/edit',
            name: 'brodTemplateEdit',
            component: () => import('@/views/help-templates/broadcasters/edit.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'edit_broadcaster_template',
                breadcrumb: [
                    {
                        text: 'broadcasters_templates',
                        to: {name: 'brodtemplate'}
                    },
                    {
                        text: 'broadcaster_template',
                        to: {
                            name: 'brodTemplateView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/resellers',
            name: 'reselltemplate',
            component: () => import('@/views/help-templates/resellers/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'resellers_templates',
                breadcrumb: [
                    {
                        text: 'resellers_templates',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/resellers/add',
            name: 'reselltemplateAdd',
            component: () => import('@/views/help-templates/resellers/add.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'add_reseller_template',
                breadcrumb: [
                    {
                        text: 'resellers_templates',
                        to: {name: 'reselltemplate'},
                    },
                    {
                        text: 'add_new_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/resellers/:id',
            name: 'resellTemplateView',
            component: () => import('@/views/help-templates/resellers/view.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'view_reseller_template',
                breadcrumb: [
                    {
                        text: 'resellers_template',
                        to: {name: 'reselltemplate'}
                    },
                    {
                        text: 'view_reseller_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/templates/resellers/:id/edit',
            name: 'resellTemplateEdit',
            component: () => import('@/views/help-templates/resellers/edit.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'edit_reseller_template',
                breadcrumb: [
                    {
                        text: 'resellers_templates',
                        to: {name: 'reselltemplate'}
                    },
                    {
                        text: 'resellers_template',
                        to: {
                            name: 'resellTemplateView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/system-info',
            name: 'systeminfo',
            component: () => import('@/views/systeminfo/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'system_info',
                breadcrumb: [
                    {
                        text: 'system_info',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/version',
            name: 'admin-version',
            component: () => import('@/views/version/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'version',
                breadcrumb: [
                    {
                        text: 'version',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/get-support',
            name: 'get-support',
            beforeEnter() {
                window.open(
                    'https://my.everestcast.com/submitticket.php?step=2&deptid=21',
                    '_blank'
                );
            },
        },
        {
            path: '/upgrade',
            name: 'upgrade-version',
            component: () => import('@/views/version/upgrade.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'version',
                breadcrumb: [
                    {
                        text: 'version',
                        to: {name: 'admin-version'}
                    },
                    {
                        text: 'upgrade',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/backup/config',
            name: 'backupConfig',
            component: () => import('@/views/backup/config.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'backup_config',
                breadcrumb: [
                    {
                        text: 'backup_config',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/backup/scheduling-status',
            name: 'backupSchedulingStatus',
            component: () => import('@/views/backup/schedule_status.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'backup_scheduling_status',
                breadcrumb: [
                    {
                        text: 'backup_scheduling_status',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/backup/manually-backup',
            name: 'backupManuallyBackup',
            component: () => import('@/views/backup/manually_backup.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'manually_backup',
                breadcrumb: [
                    {
                        text: 'manually_backup',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/backup/restore-backup',
            name: 'backupRestoreBackup',
            component: () => import('@/views/backup/restore.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'restore_backup',
                breadcrumb: [
                    {
                        text: 'restore_backup',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/backup/manually-backup-log',
            name: 'backupManuallyLog',
            component: () => import('@/views/backup/log.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'manually_backup_logs',
                breadcrumb: [
                    {
                        text: 'manually_backup_logs',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/backup/restore-log',
            name: 'restoreLog',
            component: () => import('@/views/backup/restore_log.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'restore_logs',
                breadcrumb: [
                    {
                        text: 'restore_logs',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/migration',
            name: 'migrationTool',
            component: () => import('@/views/migration/index.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'migration_tool',
                breadcrumb: [
                    {
                        text: 'migration_tool',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/migration-logs',
            name: 'migrationLog',
            component: () => import('@/views/migration/log.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'migration_logs',
                breadcrumb: [
                    {
                        text: 'migration',
                        to: {name: 'migrationTool'}
                    },
                    {
                        text: 'migration_logs',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/transfer-list',
            name: 'TransferList',
            component: () => import('@/views/migration/transfer_list.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'transfer_list',
                breadcrumb: [
                    {
                        text: 'migration_tool',
                        to: {name: 'migrationTool'}
                    },
                    {
                        text: 'transfer_list',
                        active: true,
                    }
                ],
            },
        },

        {
            path: '/login-logs',
            name: 'loginLogs',
            component: () => import('@/views/logs/login.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'login_logs',
                breadcrumb: [
                    {
                        text: 'login_logs',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/api-logs',
            name: 'apiLogs',
            component: () => import('@/views/logs/api.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'api_logs',
                breadcrumb: [
                    {
                        text: 'api_logs',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/logout',
            name: 'logout',
            meta: {
                logout: true,
            },
        },
        {
            path: '/forgot-password',
            name: 'forgotPassword',
            component: () => import('@/views/auth/forgetPassword.vue'),
            meta: {
                layout: 'full',
                pageTitle: 'forget_password',
            },
        },
        {
            path: '/admin-reset/:id/:code',
            name: 'adminReset',
            component: () => import('@/views/auth/resetPassword.vue'),
            meta: {
                checkCode: true,
                layout: 'full',
                pageTitle: 'reset_password',
            },
        },


        // broadcaster dashboard
        {
            path: '/broadcaster',
            name: 'broadcaster-home',
            component: () => import('@/views/BroadcasterPanel/dashboard/index.vue'),
            meta: {
                reload: true,
                BroadcasterAuth: true,
                pageTitle: 'home',
                breadcrumb: [
                    {
                        text: 'home',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/profile',
            name: 'broadcaster-profile',
            component: () => import('@/views/BroadcasterPanel/profile/profile.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'profile',
                breadcrumb: [
                    {
                        text: 'profile',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/billing',
            name: 'broadcaster-billing-limits',
            component: () => import('@/views/BroadcasterPanel/billing/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'billing_limits',
                breadcrumb: [
                    {
                        text: 'billing_limits',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/forgot-password',
            name: 'broadcaster-forgotPassword',
            component: () => import('@/views/BroadcasterPanel/auth/forgetPassword.vue'),
            meta: {
                layout: 'full',
                pageTitle: 'forget_password',
            },
        },
        {
            path: '/broadcaster/broadcaster-reset/:id/:code',
            name: 'broadcaster-reset',
            component: () => import('@/views/BroadcasterPanel/auth/resetPassword.vue'),
            meta: {
                brodCheckCode: true,
                layout: 'full',
                pageTitle: 'reset_password',
            },
        },
        {
            path: '/broadcaster/login',
            name: 'broadcaster-login',
            component: () => import('@/views/BroadcasterPanel/auth/Login.vue'),
            meta: {
                checkLanguage: true,
                layout: 'full',
            },
        },
        {
            path: '/broadcaster/logout',
            name: 'broadcaster-logout',
            meta: {
                BroadcasterLogout: true,
            },
        },
        {
            path: '/broadcaster/channels',
            name: 'broadcaster-channels',
            component: () => import('@/views/BroadcasterPanel/channels/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'channels',
                breadcrumb: [
                    {
                        text: 'channels',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/channels/view/:id',
            name: 'channelView',
            component: () => import('@/views/BroadcasterPanel/channels/view.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'channel',
                breadcrumb: [
                    {
                        text: 'channels',
                        to: {name: 'broadcaster-channels'}
                    },
                    {
                        text: 'view',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/channels/update/:id',
            name: 'channelEdit',
            component: () => import('@/views/BroadcasterPanel/channels/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'channel',
                breadcrumb: [
                    {
                        text: 'channels',
                        to: {name: 'broadcaster-channels'}
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/channels/create',
            name: 'channelAdd',
            component: () => import('@/views/BroadcasterPanel/channels/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'channel',
                breadcrumb: [
                    {
                        text: 'channels',
                        to: {name: 'broadcaster-channels'}
                    },
                    {
                        text: 'add',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/filemanager',
            name: 'fileManager',
            component: () => import('@/views/BroadcasterPanel/filemanager/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'filemanager',
                breadcrumb: [
                    {
                        text: 'filemanager',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/broadcaster/ftpmanagement',
            name: 'fileManagement',
            component: () => import('@/views/BroadcasterPanel/ftpManagement/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'ftpmanagement',
                breadcrumb: [
                    {
                        text: 'ftpmanagement',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/broadcaster/ftpmanagement/create',
            name: 'ftpAdd',
            component: () => import('@/views/BroadcasterPanel/ftpManagement/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'add_ftp_account',
                breadcrumb: [
                    {
                        text: 'ftpmanagement',
                        to: {name: 'fileManagement'}
                    },
                    {
                        text: 'add',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/ftpmanagement/update/:id',
            name: 'ftpEdit',
            component: () => import('@/views/BroadcasterPanel/ftpManagement/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'ftp_update',
                breadcrumb: [
                    {
                        text: 'ftpmanagement',
                        to: {name: 'fileManagement'}
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/djs',
            name: 'djs',
            component: () => import('@/views/BroadcasterPanel/djs/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'djs',
                breadcrumb: [
                    {
                        text: 'djs',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/broadcaster/djs/create',
            name: 'djsAdd',
            component: () => import('@/views/BroadcasterPanel/djs/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'djs_create',
                breadcrumb: [
                    {
                        text: 'djs',
                        to: {name: 'djs'}
                    },
                    {
                        text: 'add',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/djs/view/:id',
            name: 'djsView',
            component: () => import('@/views/BroadcasterPanel/djs/view.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'djs_view',
                breadcrumb: [
                    {
                        text: 'djs',
                        to: {name: 'djs'}
                    },
                    {
                        text: 'view',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/djs/update/:id',
            name: 'djsEdit',
            component: () => import('@/views/BroadcasterPanel/djs/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'djs_update',
                breadcrumb: [
                    {
                        text: 'djs',
                        to: {name: 'djs'}
                    },
                    {
                        text: 'djs_view',
                        to: {
                            name: 'djsView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/djs/live/view/:id',
            name: 'djsLiveView',
            component: () => import('@/views/BroadcasterPanel/djs/live-view.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'djs_live_view',
                breadcrumb: [
                    {
                        text: 'djs',
                        to: {name: 'djs'}
                    },
                    {
                        text: 'view',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/djs/live/update/:id',
            name: 'djsLiveEdit',
            component: () => import('@/views/BroadcasterPanel/djs/live-edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'djs_update',
                breadcrumb: [
                    {
                        text: 'djs',
                        to: {name: 'djs'}
                    },
                    {
                        text: 'djs_live_view',
                        to: {
                            name: 'djsLiveView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/tags',
            name: 'tags',
            component: () => import('@/views/BroadcasterPanel/tags/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'tags',
                breadcrumb: [
                    {
                        text: 'tags',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/broadcaster/tags/create',
            name: 'tagAdd',
            component: () => import('@/views/BroadcasterPanel/tags/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'tags create',
                breadcrumb: [
                    {
                        text: 'tags',
                        to: {name: 'tags'}
                    },
                    {
                        text: 'add',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/tags/view/:id',
            name: 'tagView',
            component: () => import('@/views/BroadcasterPanel/tags/view.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'tag view',
                breadcrumb: [
                    {
                        text: 'tags',
                        to: {name: 'tags'}
                    },
                    {
                        text: 'view',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/tags/update/:id',
            name: 'tagEdit',
            component: () => import('@/views/BroadcasterPanel/tags/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'tag update',
                breadcrumb: [
                    {
                        text: 'tags',
                        to: {name: 'tags'}
                    },
                    {
                        text: 'tag',
                        to: {
                            name: 'tagView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/tags/tracks/:id',
            name: 'tagsTracks',
            component: () => import('@/views/BroadcasterPanel/tags/tracks.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'tracks',
                breadcrumb: [
                    {
                        text: 'tags',
                        to: {name: 'tags'}
                    },
                    {
                        text: 'tag',
                        to: {
                            name: 'tagView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'tracks',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/tags/playlists/:id',
            name: 'tagsPlaylist',
            component: () => import('@/views/BroadcasterPanel/tags/playlists.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'playlists',
                breadcrumb: [
                    {
                        text: 'tags',
                        to: {name: 'tags'}
                    },
                    {
                        text: 'tag',
                        to: {
                            name: 'tagView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'playlists',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/playlists',
            name: 'playlists',
            component: () => import('@/views/BroadcasterPanel/playlists/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'playlists',
                breadcrumb: [
                    {
                        text: 'playlists',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/broadcaster/playlists/create',
            name: 'playlistAdd',
            component: () => import('@/views/BroadcasterPanel/playlists/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'playlist create',
                breadcrumb: [
                    {
                        text: 'playlists',
                        to: {name: 'playlists'}
                    },
                    {
                        text: 'add',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/playlists/view/:id',
            name: 'playlistView',
            component: () => import('@/views/BroadcasterPanel/playlists/view.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'playlist view',
                breadcrumb: [
                    {
                        text: 'playlists',
                        to: {name: 'playlists'}
                    },
                    {
                        text: 'view',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/playlists/update/:id',
            name: 'playlistEdit',
            component: () => import('@/views/BroadcasterPanel/playlists/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'playlist update',
                breadcrumb: [
                    {
                        text: 'playlists',
                        to: {name: 'playlists'}
                    },
                    {
                        text: 'playlist',
                        to: {
                            name: 'playlistView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/playlists/tracks/:id',
            name: 'tracks',
            component: () => import('@/views/BroadcasterPanel/tracks/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'tracks',
                breadcrumb: [
                    {
                        text: 'playlists',
                        to: {name: 'playlists'}
                    },
                    {
                        text: 'playlist',
                        to: {
                            name: 'playlistView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'tracks',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/track-meta/:id',
            name: 'track_meta',
            component: () => import('@/views/BroadcasterPanel/tracks/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'track_meta',
                breadcrumb: [
                    {
                        text: 'filemanager',
                        to: {name: 'fileManager'}
                    },
                    {
                        text: 'track_meta',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/schedule',
            name: 'schedule',
            component: () => import('@/views/BroadcasterPanel/schedule/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'schedule',
                breadcrumb: [
                    {
                        text: 'schedule',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/schedule/edit/:id',
            name: 'scheduleEdit',
            component: () => import('@/views/BroadcasterPanel/schedule/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'edit_schedule',
                breadcrumb: [
                    {
                        text: 'schedule',
                        to: {name: 'schedule'}
                    },
                    {
                        text: 'edit_schedule',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/crossfade',
            name: 'crossfade',
            component: () => import('@/views/BroadcasterPanel/crossfade/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'crossfade',
                breadcrumb: [
                    {
                        text: 'crossfade',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/normalize_volume',
            name: 'normalizevolume',
            component: () => import('@/views/BroadcasterPanel/normalizevolume/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'normalize_volume',
                breadcrumb: [
                    {
                        text: 'normalize_volume',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/recording',
            name: 'recording',
            component: () => import('@/views/BroadcasterPanel/recording/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'recording',
                breadcrumb: [
                    {
                        text: 'recording',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/geo-settings',
            name: 'geo-settings',
            component: () => import('@/views/BroadcasterPanel/geo-settings/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'geo_settings',
                breadcrumb: [
                    {
                        text: 'geo_settings',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/ip-block',
            name: 'ip-block',
            component: () => import('@/views/BroadcasterPanel/IPblock/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'ip_block',
                breadcrumb: [
                    {
                        text: 'ip_block',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/branding',
            name: 'broadcaster-branding',
            component: () => import('@/views/BroadcasterPanel/branding/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'branding',
                breadcrumb: [
                    {
                        text: 'branding',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/quick-links',
            name: 'quick-links',
            component: () => import('@/views/BroadcasterPanel/quick-links/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'quick_links',
                breadcrumb: [
                    {
                        text: 'quick_links',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/webplayer',
            name: 'webplayer',
            component: () => import('@/views/BroadcasterPanel/quick-links/webplayer.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'webplayer',
                breadcrumb: [
                    {
                        text: 'webplayer',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/social-relay',
            name: 'social-relay',
            component: () => import('@/views/BroadcasterPanel/social/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'social_relay',
                breadcrumb: [
                    {
                        text: 'social_relay',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/youtube-downloader',
            name: 'youtube-downloader',
            component: () => import('@/views/BroadcasterPanel/youtube-downloader/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'youtube_downloader',
                breadcrumb: [
                    {
                        text: 'youtube_downloader',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/youtube-log',
            name: 'youtube-log',
            component: () => import('@/views/BroadcasterPanel/youtube-downloader/log.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'youtube_download_status',
                breadcrumb: [
                    {
                        text: 'youtube_downloader',
                        to: {name: 'youtube-downloader'}
                    },
                    {
                        text: 'youtube_download_status',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/widgets',
            name: 'widgets',
            component: () => import('@/views/BroadcasterPanel/widgets/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'widgets',
                breadcrumb: [
                    {
                        text: 'widgets',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/player_builder',
            name: 'player_builder',
            component: () => import('@/views/BroadcasterPanel/widgets/player_builder.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'player_builder',
                breadcrumb: [
                    {
                        text: 'player_builder',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles',
            name: 'jingles',
            component: () => import('@/views/BroadcasterPanel/jingles/jingles/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles',
                breadcrumb: [
                    {
                        text: 'jingles',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles/create',
            name: 'jinglesAdd',
            component: () => import('@/views/BroadcasterPanel/jingles/jingles/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_create',
                breadcrumb: [
                    {
                        text: 'jingles',
                        to: {name: 'jingles'}
                    },
                    {
                        text: 'jingles_create',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles/view/:id',
            name: 'jinglesView',
            component: () => import('@/views/BroadcasterPanel/jingles/jingles/view.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_view',
                breadcrumb: [
                    {
                        text: 'jingles',
                        to: {name: 'jingles'}
                    },
                    {
                        text: 'jingles_view',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles/edit/:id',
            name: 'jingleEdit',
            component: () => import('@/views/BroadcasterPanel/jingles/jingles/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_edit',
                breadcrumb: [
                    {
                        text: 'jingles',
                        to: {name: 'jingles'}
                    },
                    {
                        text: 'jingles_view',
                        to: {
                            name: 'jinglesView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'jingles_edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles-playlists',
            name: 'jingles-playlists',
            component: () => import('@/views/BroadcasterPanel/jingles/playlists/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_playlists',
                breadcrumb: [
                    {
                        text: 'jingles_playlists',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles-playlists/create',
            name: 'jinglesPlaylistAdd',
            component: () => import('@/views/BroadcasterPanel/jingles/playlists/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_playlists_create',
                breadcrumb: [
                    {
                        text: 'jingles_playlists',
                        to: {name: 'jingles-playlists'}
                    },
                    {
                        text: 'add',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles-playlists/view/:id',
            name: 'jinglesPlaylistView',
            component: () => import('@/views/BroadcasterPanel/jingles/playlists/view.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_playlist_view',
                breadcrumb: [
                    {
                        text: 'jingles_playlists',
                        to: {name: 'jingles-playlists'}
                    },
                    {
                        text: 'view',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles-playlists/update/:id',
            name: 'jinglesPlaylistEdit',
            component: () => import('@/views/BroadcasterPanel/jingles/playlists/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_playlists_update',
                breadcrumb: [
                    {
                        text: 'jingles_playlists',
                        to: {name: 'jingles-playlists'}
                    },
                    {
                        text: 'jingles_playlist',
                        to: {
                            name: 'jinglesPlaylistView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/jingles-playlists/tracks/:id',
            name: 'jinglesTracks',
            component: () => import('@/views/BroadcasterPanel/tracks/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'jingles_playlist_tracks',
                breadcrumb: [
                    {
                        text: 'jingles_playlists',
                        to: {name: 'jingles-playlists'}
                    },
                    {
                        text: 'jingles_playlist',
                        to: {
                            name: 'jinglesPlaylistView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'tracks',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/statistics',
            name: 'broadcaster-statistics',
            component: () => import('@/views/BroadcasterPanel/statistics/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'statistics',
                breadcrumb: [
                    {
                        text: 'statistics',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/authenticated-listeners',
            name: 'authenticated_listeners',
            component: () => import('@/views/BroadcasterPanel/authenticatedListeners/index.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'authenticated_listeners',
                breadcrumb: [
                    {
                        text: 'authenticated_listeners',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/authenticated-listeners/add',
            name: 'authenticated_listeners_add',
            component: () => import('@/views/BroadcasterPanel/authenticatedListeners/add.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'authenticated_listeners_add',
                breadcrumb: [
                    {
                        text: 'authenticated_listeners',
                        to: {name: 'authenticated_listeners'}
                    },
                    {
                        text: 'add_authenticated_listener',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/broadcaster/authenticated-listeners/:id/edit',
            name: 'authenticated_listeners_edit',
            component: () => import('@/views/BroadcasterPanel/authenticatedListeners/edit.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'edit_authenticated_listener',
                breadcrumb: [
                    {
                        text: 'authenticated_listeners',
                        to: {name: 'authenticated_listeners'}
                    },
                    {
                        text: 'edit_authenticated_listener',
                        active: true,
                    },
                ],
            },
        },


        {
            path: '/broadcaster/login-logs',
            name: 'BroadcasterLoginLogs',
            component: () => import('@/views/BroadcasterPanel/logs/login.vue'),
            meta: {
                BroadcasterAuth: true,
                pageTitle: 'login_logs',
                breadcrumb: [
                    {
                        text: 'login_logs',
                        active: true,
                    }
                ],
            },
        },


        // Reseller Routes
        {
            path: '/reseller',
            name: 'reseller-home',
            component: () => import('@/views/ResellerPanel/broadcasters/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'broadcasters',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/broadcasters',
            name: 'reseller-broadcasters',
            component: () => import('@/views/ResellerPanel/broadcasters/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'broadcasters',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/broadcasters/add',
            name: 'reseller-broadAdd',
            component: () => import('@/views/ResellerPanel/broadcasters/add.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'add_broadcaster',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        to: {name: 'reseller-broadcasters'}
                    },
                    {
                        text: 'add_broadcaster',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/broadcasters/:id',
            name: 'reseller-brodView',
            props: route => ({id: Number(route.params.id)}),
            component: () => import('@/views/ResellerPanel/broadcasters/view.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'view_broadcaster',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        to: {name: 'reseller-broadcasters'}
                    },
                    {
                        text: 'view_broadcaster',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/broadcasters/:id/edit',
            name: 'reseller-brodEdit',
            component: () => import('@/views/ResellerPanel/broadcasters/edit.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'edit_broadcaster',
                breadcrumb: [
                    {
                        text: 'broadcasters',
                        to: {name: 'reseller-broadcasters'}
                    },
                    {
                        text: 'view_broadcaster',
                        to: {
                            name: 'reseller-brodView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit_broadcaster',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/profile',
            name: 'reseller-profile',
            component: () => import('@/views/ResellerPanel/profile/profile.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'profile',
                breadcrumb: [
                    {
                        text: 'profile',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/branding',
            name: 'reseller-branding',
            component: () => import('@/views/ResellerPanel/branding/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'branding',
                breadcrumb: [
                    {
                        text: 'branding',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/billing',
            name: 'reseller-billing',
            component: () => import('@/views/ResellerPanel/billing/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'billing_limits',
                breadcrumb: [
                    {
                        text: 'billing_limits',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/api-setting',
            name: 'reseller-api-setting',
            component: () => import('@/views/ResellerPanel/Api/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'api_setting',
                breadcrumb: [
                    {
                        text: 'api_setting',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/forgot-password',
            name: 'reseller-forgotPassword',
            component: () => import('@/views/ResellerPanel/auth/forgetPassword.vue'),
            meta: {
                layout: 'full',
                pageTitle: 'forget_password',
            },
        },
        {
            path: '/reseller/reseller-reset/:id/:code',
            name: 'reseller-reset',
            component: () => import('@/views/ResellerPanel/auth/resetPassword.vue'),
            meta: {
                resellCheckCode: true,
                layout: 'full',
                pageTitle: 'reset_password',
            },
        },

        {
            path: '/reseller/login',
            name: 'reseller-login',
            component: () => import('@/views/ResellerPanel/auth/Login.vue'),
            meta: {
                layout: 'full',
            },
        },
        {
            path: '/get-support',
            name: 'get-support',
            beforeEnter() {
                window.open(
                    'https://my.everestcast.com/submitticket.php?step=2&deptid=21',
                    '_blank'
                );
            },
        },
        {
            path: '/reseller/smtp',
            name: 'ResellerSmtp',
            component: () => import('@/views/ResellerPanel/smtp/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'smtp_configuration',
                breadcrumb: [
                    {
                        text: 'smtp_configuration',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/templates/broadcasters',
            name: 'resellerBrodtemplate',
            component: () => import('@/views/ResellerPanel/help-templates/broadcasters/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'broadcasters_templates',
                breadcrumb: [
                    {
                        text: 'broadcasters_templates',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/templates/broadcasters/add',
            name: 'resellerBrodTemplateAdd',
            component: () => import('@/views/ResellerPanel/help-templates/broadcasters/add.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'add_broadcaster_template',
                breadcrumb: [
                    {
                        text: 'broadcasters_templates',
                        to: {name: 'resellerBrodtemplate'}
                    },
                    {
                        text: 'add_new_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/templates/broadcasters/:id',
            name: 'resellerBrodTemplateView',
            component: () => import('@/views/ResellerPanel/help-templates/broadcasters/view.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'view_broadcaster_template',
                breadcrumb: [
                    {
                        text: 'broadcasters_templates',
                        to: {name: 'resellerBrodtemplate'}
                    },
                    {
                        text: 'view_broadcaster_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/templates/broadcasters/:id/edit',
            name: 'resellerBrodTemplateEdit',
            component: () => import('@/views/ResellerPanel/help-templates/broadcasters/edit.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'edit_broadcaster_template',
                breadcrumb: [
                    {
                        text: 'broadcasters_templates',
                        to: {name: 'resellerBrodtemplate'}
                    },
                    {
                        text: 'broadcaster_template',
                        to: {
                            name: 'resellerBrodTemplateView',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/templates',
            name: 'reseller-templates',
            component: () => import('@/views/ResellerPanel/templates/index.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'templates',
                breadcrumb: [
                    {
                        text: 'templates',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/template/:id',
            name: 'reseller-template',
            component: () => import('@/views/ResellerPanel/templates/view.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'view_template',
                breadcrumb: [
                    {
                        text: 'templates',
                        to: {name: 'reseller-templates'}
                    },
                    {
                        text: 'view_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/template/:id/edit',
            name: 'reseller-template-edit',
            component: () => import('@/views/ResellerPanel/templates/edit.vue'),
            meta: {
                ResellerAuth: true,
                pageTitle: 'edit_template',
                breadcrumb: [
                    {
                        text: 'templates',
                        to: {name: 'reseller-templates'}
                    },
                    {
                        text: 'view_template',
                        to: {
                            name: 'reseller-template',
                            params: ':id'
                        }
                    },
                    {
                        text: 'edit_template',
                        active: true,
                    },
                ],
            },
        },
        {
            path: '/reseller/login-logs',
            name: 'ResellerLoginLogs',
            component: () => import('@/views/ResellerPanel/logs/login.vue'),
            meta: {
                requiresAuth: true,
                pageTitle: 'login_logs',
                breadcrumb: [
                    {
                        text: 'login_logs',
                        active: true,
                    }
                ],
            },
        },
        {
            path: '/reseller/logout',
            name: 'reseller-logout',
            meta: {
                ResellerLogout: true,
            },
        },
        {
            path: '/player/:port',
            name: 'player',
            component: () => import('@/views/BroadcasterPanel/quick-links/webplayer.vue'),
            meta: {
                layout: 'full',
            },
        },
        {
            path: '/custom-player/:port',
            name: 'custom_player',
            component: () => import('@/views/BroadcasterPanel/widgets/widjet_player_builder.vue'),
            meta: {
                layout: 'full',
            },
        },
        {
            path: '/accessdenied',
            name: 'accessdenied',
            component: () => import('@/views/error/AccessDenied'),
            meta: {
                layout: 'full',
            },
        },
        {
            path: '*',
            redirect: 'error-404',
        },
    ],
})

router.afterEach(() => {
    // Remove initial loading
    const appLoading = document.getElementById('loading-bg')
    if (appLoading) {
        appLoading.style.display = 'none'
    }
})

router.beforeEach((to, from, next) => {
    if (to.meta.requiresAuth) {

        if (to.query.token) {
            let tok = to.query.token;
            localStorage.setItem('token', tok.toString());
        }

        if (!localStorage.getItem('token')) {
            return router.push({name: 'login'})
        } else {
            let page = to.name;
            axios.post(window.location.origin + '/api/auth/checkAuthToken', {
                token: localStorage.getItem('token')
            })
                .then(response => {
                    if (response.data.status == 'invalid-language') {
                        return router.push({name: 'license'})
                    } else if (response.data.status == 'unauthorized' || response.data.status == 'error') {
                        localStorage.removeItem('token')
                        return router.push({name: 'login'})
                    }
                })
        }

        return next()
    }

    if (to.meta.logout) {
        if (localStorage.getItem('token')) {
            localStorage.removeItem('token')
        }
        return router.push({name: 'login'})
    }

    if (to.meta.checkCode) {
        let id = to.params.id
        let code = to.params.code
        axios.get(window.location.origin + '/api/admin-reset/' + id + '/' + code)
            .then(response => {
                if (response.data.status == 'error') {
                    return router.push({
                        name: 'login',
                        query: {message: 'invalid-reset-code'}
                    })
                }
            })
    }
    if (to.meta.BroadcasterAuth) {
        if (to.query.token) {
            let tok = to.query.token;
            localStorage.setItem('broadcaster_token', tok);
            let routeData = router.resolve({name: 'broadcaster-home'});
            window.open(routeData.href, "_self");
        }


        if (!localStorage.getItem('broadcaster_token')) {
            return router.push({name: 'broadcaster-login'})
        } else {
            axios.post(window.location.origin + '/api/broadcasters-auth/checkAuthToken?token=' + localStorage.getItem('broadcaster_token'))
                .then(response => {
                    if (response.data.status == 'invalid-language') {
                        localStorage.removeItem('broadcaster_token')
                        return router.push({name: 'broadcaster-login', query: {message: 'something_went_wrong'}})
                    }
                    if (response.data.status != 'authorized') {
                        localStorage.removeItem('broadcaster_token')
                        return router.push({name: 'broadcaster-login'})
                    }
                })
        }

        return next()
    }

    if (to.meta.brodCheckCode) {
        let id = to.params.id
        let code = to.params.code
        axios.get(window.location.origin + '/api/broadcaster-reset/' + id + '/' + code)
            .then(response => {
                if (response.data.status == 'error') {
                    return router.push({
                        name: 'broadcaster-login',
                        query: {message: 'invalid-reset-code'}
                    })
                }
            })
    }

    if (to.meta.BroadcasterLogout) {
        if (localStorage.getItem('broadcaster_token')) {
            localStorage.removeItem('broadcaster_token')
        }
        return router.push({name: 'broadcaster-login'})
    }

    // Reseller

    if (to.meta.ResellerAuth) {
        let st_name = 'Reseller Panel'
        if (to.query.token) {
            let tok = to.query.token;
            localStorage.setItem('reseller_token', tok);
            let routeData = router.resolve({name: 'reseller-home'});
            window.open(routeData.href, "_self");
        }

        if (!localStorage.getItem('reseller_token')) {
            return router.push({name: 'reseller-login'})
        } else {
            axios.post(window.location.origin + '/api/reseller/checkAuthToken?token=' + localStorage.getItem('reseller_token'))
                .then(response => {
                    if (response.data.status == 'invalid-language') {
                        localStorage.removeItem('reseller_token')
                        return router.push({name: 'reseller-login', query: {message: 'something_went_wrong'}})
                    }
                    if (response.data.status != 'authorized') {
                        localStorage.removeItem('reseller_token')
                        return router.push({name: 'reseller-login'})
                    } else {
                        Vue.nextTick(() => {
                            document.title = response.data.data + ' | ' + to.meta.pageTitle
                        })
                    }
                })
        }

        return next()
    }

    if (to.meta.resellCheckCode) {
        let id = to.params.id
        let code = to.params.code
        axios.get(window.location.origin + '/api/reseller-reset/' + id + '/' + code)
            .then(response => {
                if (response.data.status == 'error') {
                    return router.push({
                        name: 'reseller-login',
                        query: {message: 'invalid-reset-code'}
                    })
                }
            })
    }

    if (to.meta.ResellerLogout) {
        if (localStorage.getItem('reseller_token')) {
            localStorage.removeItem('reseller_token')
        }
        return router.push({name: 'reseller-login'})
    }

    return next()
})

export default router
